==> ixnetwork_restpy-1.0.35-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/topology/pbbevpnparameter.py <==
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PbbEVpnParameter(Base):
	"""The PbbEVpnParameter class encapsulates a user managed pbbEVpnParameter node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PbbEVpnParameter property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'pbbEVpnParameter'

	def __init__(self, parent):
		super(PbbEVpnParameter, self).__init__(parent)

	@property
	def BMac(self):
		"""Broadcast MAC addresses of the devices

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bMac')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def UsePbbEVpnParameters(self):
		"""Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			bool
		"""
		return self._get_attribute('usePbbEVpnParameters')
	@UsePbbEVpnParameters.setter
	def UsePbbEVpnParameters(self, value):
		self._set_attribute('usePbbEVpnParameters', value)

	def update(self, UsePbbEVpnParameters=None):
		"""Updates a child instance of pbbEVpnParameter on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, UsePbbEVpnParameters=None):
		"""Adds a new pbbEVpnParameter node on the server and retrieves it in this instance.

		Args:
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			self: This instance with all currently retrieved pbbEVpnParameter data using find and the newly added pbbEVpnParameter data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the pbbEVpnParameter data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, UsePbbEVpnParameters=None):
		"""Finds and retrieves pbbEVpnParameter data from the server.

		All named parameters support regex and can be used to selectively retrieve pbbEVpnParameter data from the server.
		By default the find method takes no parameters and will retrieve all pbbEVpnParameter data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			self: This instance with matching pbbEVpnParameter data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pbbEVpnParameter data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pbbEVpnParameter data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, BMac=None):
		"""Base class infrastructure that gets a list of pbbEVpnParameter device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			BMac (str): optional regex of bMac

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

==> ixnetwork_restpy-1.0.41-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/topology/pbbevpnparameter.py <==
# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PbbEVpnParameter(Base):
	"""The PbbEVpnParameter class encapsulates a user managed pbbEVpnParameter node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PbbEVpnParameter property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	__slots__ = ()
	_SDM_NAME = 'pbbEVpnParameter'

	def __init__(self, parent):
		super(PbbEVpnParameter, self).__init__(parent)

	@property
	def BMac(self):
		"""Broadcast MAC addresses of the devices

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bMac')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def UsePbbEVpnParameters(self):
		"""Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			bool
		"""
		return self._get_attribute('usePbbEVpnParameters')
	@UsePbbEVpnParameters.setter
	def UsePbbEVpnParameters(self, value):
		self._set_attribute('usePbbEVpnParameters', value)

	def update(self, UsePbbEVpnParameters=None):
		"""Updates a child instance of pbbEVpnParameter on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, UsePbbEVpnParameters=None):
		"""Adds a new pbbEVpnParameter node on the server and retrieves it in this instance.

		Args:
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			self: This instance with all currently retrieved pbbEVpnParameter data using find and the newly added pbbEVpnParameter data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the pbbEVpnParameter data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, UsePbbEVpnParameters=None):
		"""Finds and retrieves pbbEVpnParameter data from the server.

		All named parameters support regex and can be used to selectively retrieve pbbEVpnParameter data from the server.
		By default the find method takes no parameters and will retrieve all pbbEVpnParameter data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
			UsePbbEVpnParameters (bool): Flag to determine whether optional PBB EVPN parameters are provided.

		Returns:
			self: This instance with matching pbbEVpnParameter data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pbbEVpnParameter data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pbbEVpnParameter data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, BMac=None):
		"""Base class infrastructure that gets a list of pbbEVpnParameter device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			BMac (str): optional regex of bMac

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())
